        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 20 <strong>control</strong><br>0,1,6,7,10,13,14,16,17,18,20,23,30,34,36,37,38,40,45,47';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 18 <br>3,4,5,8,9,11,12,15,19,24,25,26,27,29,33,35,41,44';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260510 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 13 <br>2,21,22,28,31,32,39,42,43,46,48,49,50';}
}
